import type { Plugin } from '../entity';
export interface Storage {
    getItem(key: string): string | null;
    setItem(key: string, value: string): void;
}
export interface AsyncStorage {
    getItem(key: string): Promise<string | null>;
    setItem(key: string, value: string): Promise<void>;
}
/**
 * Persistence plug-in enables storing entity values to `localStorage` (default),
 * `sessionStorage` or custom storage (must implement the Web Storage API).
 *
 * @param key - unique identifier
 * @param options - optional config for storage and serialization/deserialization
 */
export declare function persistence(key: string, options?: {
    storage?: Storage | AsyncStorage | 'local' | 'session';
    serializeFn?: (value: any) => string | Promise<string>;
    deserializeFn?: (value: string) => any | Promise<any>;
}): Plugin;
